@@ -80,8 +80,10 @@ sub run {
     }
 
     if ($copyright_path->is_open_ok) {
-        _check_dep5_copyright($info, $copyright_path);
-        _check_apache_notice_files($info, $group, $copyright_path);
+        my $contents = $copyright_path->file_contents;
+
+        _check_dep5_copyright($info, $contents);
+        _check_apache_notice_files($info, $group, $contents);
     }
     return;
 }
@@ -102,20 +104,20 @@ sub _find_dep5_version {
     if (
         $uri =~ s{ https?://wiki\.debian\.org/
                                 Proposals/CopyrightFormat\b}{}xsm
-      ){
+    ){
         $version = '0~wiki';
         $uri =~ m,^\?action=recall&rev=(\d+)$,
           and $version = "$version~$1";
         return $version;
     }
-    if ($uri =~ m,^https?://dep\.debian\.net/deps/dep5/?$,) {
+    if ($uri =~ m,^https?://dep(-team\.pages)?\.debian\.net/deps/dep5/?$,) {
         $version = '0+svn';
         return $version;
     }
     if (
         $uri =~ s{\A https?://svn\.debian\.org/
                                   wsvn/dep/web/deps/dep5\.mdwn\b}{}xsm
-      ){
+    ){
         $version = '0+svn';
         $uri =~ m,^\?(?:\S+[&;])?rev=(\d+)(?:[&;]\S+)?$,
           and $version = "$version~$1";
@@ -124,7 +126,7 @@ sub _find_dep5_version {
     if (
         $uri =~ s{ \A https?://(?:svn|anonscm)\.debian\.org/
                                     viewvc/dep/web/deps/dep5\.mdwn\b}{}xsm
-      ){
+    ){
         $version = '0+svn';
         $uri =~ m{\A \? (?:\S+[&;])?
                              (?:pathrev|revision|rev)=(\d+)(?:[&;]\S+)?
@@ -137,7 +139,7 @@ sub _find_dep5_version {
                        https?://www\.debian\.org/doc/
                        (?:packaging-manuals/)?copyright-format/(\d+\.\d+)/?
                    \Z}xsm
-      ){
+    ){
         $version = $1;
         return $version;
     }
@@ -147,11 +149,11 @@ sub _find_dep5_version {
 }
 
 sub _check_apache_notice_files {
-    my ($info, $group, $copyright_path) = @_;
+    my ($info, $group, $contents) = @_;
 
     my @procs = $group->get_processables('binary');
     return if not @procs;
-    return if $copyright_path->file_contents !~ m/apache[-\s]+2\./i;
+    return if $contents !~ m/apache[-\s]+2\./i;
 
     my @notice_files = grep {
               $_->basename =~ m/^NOTICE(\.txt)?$/
@@ -175,8 +177,7 @@ sub _check_apache_notice_files {
 }
 
 sub _check_dep5_copyright {
-    my ($info, $copyright_path) = @_;
-    my $contents = $copyright_path->file_contents;
+    my ($info, $contents) = @_;
     my (@dep5, @lines);
 
     if (    $contents =~ m/^Files-Excluded:/
@@ -190,12 +191,12 @@ sub _check_dep5_copyright {
                (?:^ | \n)
                (?i: format(?: [:] |[-\s]spec) )
                (?: . | \n\s+ )*
-               (?: /dep[5s]?\b | \bDEP-?5\b
+               (?: /dep[5s]?\b | \bDEP ?5\b
                  | [Mm]achine-readable\s(?:license|copyright)
                  | /copyright-format/ | CopyrightFormat
                  | VERSIONED_FORMAT_URL
                ) }x
-      ){
+    ){
 
         tag 'no-dep5-copyright';
         return;
@@ -237,7 +238,7 @@ sub _check_dep5_copyright {
     }
 
     # We are reasonably certain that we're dealing
-    # with an up-to-date DEP-5 format. Let's try to do
+    # with an up-to-date DEP 5 format. Let's try to do
     # more strict checks.
     eval {
         open(my $fd, '<', \$contents);
@@ -285,7 +286,8 @@ sub _parse_dep5 {
       and none { defined $first_para->{$_} } qw(comment disclaimer);
     tag 'missing-explanation-for-repacked-upstream-tarball'
       if $info->repacked
-      and none { defined $first_para->{$_} } qw(comment files-excluded);
+      and none { defined $first_para->{$_} } qw(comment files-excluded)
+      and ($first_para->{'source'} // '') =~ m{^https?://};
 
     my (undef, $full_license_field, undef,@short_licenses_field)
       =parse_license($first_para->{'license'}, 1);
@@ -328,7 +330,8 @@ sub _parse_dep5 {
         if (defined $license and not defined $files) {
             my (undef, $full_license, $short_license,@short_licenses)
               = parse_license($license, $current_line);
-
+            check_incomplete_creative_commons_license($short_license,
+                $license, $current_line);
             # Standalone license paragraph
             if (defined($short_license) and $short_license =~ /\s++\|\s++/) {
                 tag 'pipe-symbol-used-as-license-disjunction', $short_license,
@@ -425,6 +428,8 @@ sub _parse_dep5 {
 
             my ($found_license, $full_license, $short_license, @short_licenses)
               = parse_license($license, $current_line);
+            check_incomplete_creative_commons_license($short_license,
+                $license, $current_line);
             if (defined($short_license) and $short_license =~ /\s++\|\s++/) {
                 tag 'pipe-symbol-used-as-license-disjunction', $short_license,
                   "(paragraph at line $current_line)";
@@ -685,6 +690,20 @@ sub check_files_excluded {
     return;
 }
 
+sub check_incomplete_creative_commons_license {
+    my ($short_license, $license, $current_line) = @_;
+    return unless $short_license and $license;
+
+    my $num_lines = $license =~ tr/\n//;
+    tag 'incomplete-creative-commons-license', $short_license,
+      "(paragraph at line $current_line)"
+      if $short_license =~ m,^cc-,
+      and $num_lines > 0
+      and $num_lines < 20;
+
+    return;
+}
+
 1;
 
 # Local Variables:
